@@ -19,7 +19,7 @@ def courses():
     """Permet de gérer la liste des cours suivis"""
     pass
 
-@click.argument("courses", type=click.Choice(["amal", "rld"]), nargs=-1)
+@click.argument("courses", type=click.Choice(["amal", "rld", "rital"]), nargs=-1)
 @courses.command("add")
 def courses_add(courses: List[str]):
     """Ajout de cours"""
@@ -27,16 +27,28 @@ def courses_add(courses: List[str]):
     configuration.courses.update(courses)
     configuration.save()
 
+@click.argument("courses", type=click.Choice(["amal", "rld", "rital"]), nargs=-1)
+@courses.command("rm")
+def courses_rm(courses: List[str]):
+    """Enlever un cours"""
+    configuration = Configuration()
+    for course in courses:
+        configuration.courses.remove(course)
+    configuration.save()
+
+
 @courses.command("list")
 def courses_list():
     """Liste des cours"""
     for course in Configuration().courses:
         print(course)
 
+@click.option("--no-self-update", is_flag=True)
 @main.command()
-def update():
+def update(no_self_update: bool):
     """Mettre à jour l'ensemble des modules pour les cours suivis"""
-    check_last_masterdac(original_args)
+    if not no_self_update:
+        check_last_masterdac(original_args)
 
     # Check that package are installed
 
@@ -47,6 +59,8 @@ def update():
     for course in configuration.courses:
         getattr(install, course)(processed)
 
+    print("Don't forget to download the datasets with `master-dac download-datasets`")
+
 @main.command()
 def download_datasets():
     """Mettre à jour l'ensemble des jeux de données pour les cours suivis"""
